==> gnome-system-tools-0.32.0.tar.bz2: gnome-system-tools-0.32.0/src/boot/callbacks.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/* callbacks.h: this file is part of boot-admin, a ximian-setup-tool frontend 
 * for boot administration.
 * 
 * Copyright (C) 2000-2001 Ximian, Inc.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 *
 * Authors: Tambet Ingo <tambet@ximian.com>.
 */

#ifndef __CALLBACKS_H
#define __CALLBACKS_H

#include <gnome.h>

void      on_boot_table_default_toggled (GtkWidget*, gchar*, gpointer);
void	  on_boot_table_cursor_changed	(GtkTreeSelection*, gpointer);
void      on_boot_delete_clicked    (GtkButton *button, gpointer data);
void      on_boot_settings_clicked  (GtkButton *button, gpointer data);
void      on_boot_append_browse_clicked (GtkButton *button, gpointer data);
void      on_boot_default_clicked   (GtkButton *button, gpointer data);
void      on_main_dialog_update_complexity (GstDialog *main_dialog, gpointer data);

void      callbacks_actions_set_sensitive      (gboolean state);
gboolean  callbacks_conf_read_failed_hook (GstTool *tool, GstReportLine *rline, gpointer data);

void on_use_password_clicked (GtkWidget *use_password, gpointer gdata);

void on_popup_add_activate (gpointer, guint, GtkWidget*);
void on_popup_settings_activate (gpointer, guint, GtkWidget*);
void on_popup_delete_activate (gpointer, guint, GtkWidget*);
gboolean on_boot_table_button_press (GtkTreeView*, GdkEventButton*, gpointer);

void on_boot_add_clicked (GtkButton*, gpointer);
void on_boot_settings_clicked (GtkButton*, gpointer);

#endif /* CALLBACKS_H */

==> gnome-system-tools-0.34.0.tar.bz2: gnome-system-tools-0.34.0/src/boot/callbacks.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/* callbacks.h: this file is part of boot-admin, a ximian-setup-tool frontend 
 * for boot administration.
 * 
 * Copyright (C) 2000-2001 Ximian, Inc.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 *
 * Authors: Tambet Ingo <tambet@ximian.com>.
 */

#ifndef __CALLBACKS_H
#define __CALLBACKS_H

#include <gnome.h>

void      on_boot_table_default_toggled (GtkWidget*, gchar*, gpointer);
void	  on_boot_table_cursor_changed	(GtkTreeSelection*, gpointer);
void      on_boot_delete_clicked    (GtkButton *button, gpointer data);
void      on_boot_settings_clicked  (GtkButton *button, gpointer data);
void      on_boot_append_browse_clicked (GtkButton *button, gpointer data);
void      on_boot_default_clicked   (GtkButton *button, gpointer data);
void      on_main_dialog_update_complexity (GstDialog *main_dialog, gpointer data);

void      callbacks_actions_set_sensitive      (gboolean state);
gboolean  callbacks_conf_read_failed_hook (GstTool *tool, GstReportLine *rline, gpointer data);

void on_use_password_clicked (GtkWidget *use_password, gpointer gdata);

void on_popup_add_activate (GtkAction*, gpointer);
void on_popup_settings_activate (GtkAction*, gpointer);
void on_popup_delete_activate (GtkAction*, gpointer);
gboolean on_boot_table_button_press (GtkTreeView*, GdkEventButton*, gpointer);

void on_boot_add_clicked (GtkButton*, gpointer);
void on_boot_settings_clicked (GtkButton*, gpointer);

#endif /* CALLBACKS_H */
